@@ -18,8 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#pragma implementation
-
 #include "ItemList.h"
 #include "TagMenu.h"
 
@@ -508,7 +506,23 @@ void ItemList::on_itemList_drop_drag_data_received(
 	context->drag_finish(false, false, time);
 }
 
-
+class Untagged : public OpSet<string>, public Tagcoll::Consumer<string, Tag>
+{
+protected:
+	virtual void consumeItemUntagged(const string& item) { *this += item; }
+	virtual void consumeItem(const string& item, const OpSet<Tag>& tags)
+	{
+		if (tags.empty())
+			*this += item;
+	}
+	virtual void consumeItemsUntagged(const OpSet<string>& items) { *this += items; }
+	virtual void consumeItems(const OpSet<string>& items, const OpSet<Tag>& tags)
+	{
+		if (tags.empty())
+			*this += items;
+	}
+public:
+};
 
 void ItemList::updateList()
 {
@@ -519,7 +533,8 @@ void ItemList::updateList()
 	if (_tagset.empty())
 	{
 		// Display untagged items
-		OpSet<string> items = doc.collection().getUntaggedItems();
+		Untagged items;
+		doc.collection().output(items);
 
 		Gtk::TreeModel::Row row;
 		itemListModel->clear();
@@ -557,7 +572,7 @@ void ItemList::updateList()
 
 	time_t end = time(NULL);
 	if (end != start)
-		fprintf(stderr, "ItemList::updateList: %d seconds\n", (end-start));
+		fprintf(stderr, "ItemList::updateList: %ld seconds\n", (end-start));
 }
 
 map< string, TagSet > ItemList::getAllItems()
