@@ -27,12 +27,12 @@ using namespace std;
 namespace Tagcoll
 {
 
-std::string Converter<Tag, std::string>::operator()(const Tag& item)
+std::string TCEConverter::operator()(const Tag& item) const
 {
 	return item.fullname();
 }
 
-OpSet<std::string> Converter<Tag, std::string>::operator()(const OpSet<Tag>& items)
+OpSet<std::string> TCEConverter::operator()(const OpSet<Tag>& items) const
 {
 	OpSet<std::string> res;
 	for (OpSet<Tag>::const_iterator i = items.begin();
@@ -42,12 +42,12 @@ OpSet<std::string> Converter<Tag, std::string>::operator()(const OpSet<Tag>& ite
 	return res;
 }
 
-Tag Converter<std::string, Tag>::operator()(const std::string& item)
+Tag TCEConverter::operator()(const std::string& item) const
 {
 	return _voc.obtainTag(item);
 }
 
-OpSet<Tag> Converter<std::string, Tag>::operator()(const OpSet<std::string>& items)
+OpSet<Tag> TCEConverter::operator()(const OpSet<std::string>& items) const
 {
 	OpSet<Tag> res;
 	for (OpSet<std::string>::const_iterator i = items.begin();
