@@ -28,33 +28,22 @@ namespace Tagcoll
 {
 
 /**
- * Convert Tags into strings
+ * Convert Tags into strings and strings into tags
  */
-template<>
-class Converter<Tag, std::string>
+class TCEConverter : public Converter<Tag, std::string>, public Converter<std::string, Tag>
 {
-public:
-	std::string operator()(const Tag& item);
-	OpSet<std::string> operator()(const OpSet<Tag>& items);
-};
-
-/**
- * Convert strings into tags
- */
-template<>
-class Converter<std::string, Tag>
-{
-protected:
 	FacetSet& _voc;
-
 public:
-	Converter(FacetSet& voc) : _voc(voc) {}
+	TCEConverter(FacetSet& voc) : _voc(voc) {}
 
-	Tag operator()(const std::string& item);
-	OpSet<Tag> operator()(const OpSet<std::string>& items);
+	std::string operator()(const Tag& item) const;
+	OpSet<std::string> operator()(const OpSet<Tag>& items) const;
+
+	Tag operator()(const std::string& item) const;
+	OpSet<Tag> operator()(const OpSet<std::string>& items) const;
 };
 
-};
+}
 
 // vim:set ts=4 sw=4:
 #endif
