@@ -21,14 +21,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#pragma interface
-
 #include <sigc++/sigc++.h>
 
-//#include <tagcoll/TagCollection.h>
+//#include <tagcoll/CardinalityStore.h>
 #include <tagcoll/InputMerger.h>
 #include <tagcoll/ParserBase.h>
-#include <tagcoll/TagcollConsumer.h>
 #include <tagcoll/Patches.h>
 #include "Tag.h"
 #include "TagSet.h"
@@ -55,14 +52,14 @@ protected:
 	type_signal_filename_changed _signal_filename_changed;
 
 public:
-	TagcollDocument() throw () : _undoTail(0) {}
+	TagcollDocument() : _undoTail(0) {}
 	virtual ~TagcollDocument() {}
 	
-	Tagcoll::TaggedCollection<ITEM, Tag>& collection() throw () { return _collection; }
-	const Tagcoll::TaggedCollection<ITEM, Tag>& collection() const throw () { return _collection; }
+	Tagcoll::Collection<ITEM, Tag>& collection() { return _collection; }
+	const Tagcoll::Collection<ITEM, Tag>& collection() const { return _collection; }
 
-	FacetSet& vocabulary() throw () { return _facets; }
-	const FacetSet& vocabulary() const throw () { return _facets; }
+	FacetSet& vocabulary() { return _facets; }
+	const FacetSet& vocabulary() const { return _facets; }
 
 	// Apply a change, appending the reverse change in the undo buffer
 	void applyChange(const Tagcoll::PatchList<ITEM, Tag>& change);
@@ -73,16 +70,16 @@ public:
 	void undo();
 	void redo();
 
-	void load(const std::string& file) throw (FileException, ParserException);
-	void loadDebtags() throw (FileException, ParserException);
-	void save(const std::string& file) throw (FileException);
+	void load(const std::string& file);
+	void loadDebtags();
+	void save(const std::string& file);
 
-	void output(Tagcoll::TagcollConsumer<ITEM, Tag>& consumer) throw ();
+	void output(Tagcoll::Consumer<ITEM, Tag>& consumer);
 
-	const std::string& fileName() const throw () { return _fileName; }
+	const std::string& fileName() const { return _fileName; }
 
-	type_signal_changed signal_changed() throw () { return _signal_changed; }
-	type_signal_filename_changed signal_filename_changed() throw () { return _signal_filename_changed; }
+	type_signal_changed signal_changed() { return _signal_changed; }
+	type_signal_filename_changed signal_filename_changed() { return _signal_filename_changed; }
 
 	virtual void do_changed();
 	virtual void do_filename_changed();
