@@ -4,15 +4,11 @@
 
 #include "Serializer.h"
 
-#include <tagcoll/TagcollConsumer.cc>
-#include <tagcoll/TagcollFilter.cc>
-#include <tagcoll/FilterChain.cc>
 #include <tagcoll/InputMerger.cc>
 #include <tagcoll/ItemGrouper.cc>
 #include <tagcoll/OpSet.cc>
 #include <tagcoll/Patches.cc>
 #include <tagcoll/Serializer.cc>
-#include <tagcoll/SerializationFilters.cc>
 #include <tagcoll/TextFormat.cc>
 
 using namespace Tagcoll;
@@ -21,13 +17,19 @@ using namespace Tagcoll;
 
 template class OpSet<Tag>;
 template class OpSet<Facet>;
-template class TagcollConsumer<string, Tag>;
+template class Consumer<string, Tag>;
 template class InputMerger<string, Tag>;
 template class ItemGrouper<string, Tag>;
 template class PatchList<string, Tag>;
-template class Serializer<string, Tag>;
-template class FromStrings<string, Tag>;
-template class ToStrings<string, Tag>;
+template class Converter<string, Tag>;
+template class Converter<Tag, string>;
 template class TextFormat<string, Tag>;
 
+/*
+#include "TagcollDocument.h"
+#include "TagcollDocument.cc"
+
+template class TagcollDocument<string>;
+*/
+
 // vim:set ts=4 sw=4:
